/* Webcamoid, webcam capture application.
 * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#ifndef EQUALIZEELEMENT_H
#define EQUALIZEELEMENT_H

#include <ak.h>
#include <akutils.h>

#include "pixelstructs.h"

class EqualizeElement: public AkElement
{
    Q_OBJECT

    public:
        explicit EqualizeElement();

    private:
        QVector<quint64> histogram(const QImage &img) const;
        QVector<quint64> cumulativeHistogram(const QVector<quint64> &histogram) const;
        QVector<quint8> equalizationTable(const QImage &img) const;

    public slots:
        AkPacket iStream(const AkPacket &packet);
};

#endif // EQUALIZEELEMENT_H
